## This file generated by InlineX::C2XS (version 0.17) using Inline::C (version 0.5002)
package Math::GMPq::Random;
use strict;
use warnings;

require Exporter;
*import = \&Exporter::import;
require DynaLoader;

$Math::GMPq::Random::VERSION = '0.33';

DynaLoader::bootstrap Math::GMPq::Random $Math::GMPq::Random::VERSION;

@Math::GMPq::Random::EXPORT = ();
@Math::GMPq::Random::EXPORT_OK = ();

sub dl_load_flags {0} # Prevent DynaLoader from complaining and croaking

1;
